@@ -4,7 +4,7 @@ from time import sleep
 
 
 
-__version__ = '1.0.5'
+__version__ = '1.0.6'
 class AlegriaDeBrincar:
     def __init__(self):
         self.c = {}
@@ -24,6 +24,7 @@ class AlegriaDeBrincar:
             AlegriaDeBrincar.insertDay(self)
             print("Checando produtos")
             AlegriaDeBrincar.insertProduto(self)
+            print("Enviando Status")
             AlegriaDeBrincar.insertStatus(self)
             print("Aguardando proxima rodada")
             sleep(self.c["check"])
@@ -126,8 +127,8 @@ class AlegriaDeBrincar:
         sql.close()
 
     def insertSell(self):
-        string = "SELECT TV.DATAEHORACADASTRO,TV.CONTROLE,TV.NUMERONFCCE,TP.CODESPECIE,cast((replace(TP.VALORPAGOVARCHAR,',','.')) as float) as total FROM TVENDANFCE AS TV INNER JOIN TFORMAPAGAMENTONFCE AS TP on TP.CODNFCE = TV.NUMERONFCCE WHERE TV.DATAEHORACADASTRO > '" + str(AlegriaDeBrincar.getLastDataInsert(self,"vendas")) + "' and TV.DATAEHORACADASTRO >= dateadd (-"+ str(self.c["cacheDay"])+" day to current_date) and TP.VALORPAGOVARCHAR <> '0,00'"
-        
+        string = "SELECT TV.DATAEHORACADASTRO,TV.CONTROLE,TV.NUMERONFCCE,TP.CODESPECIE,cast((replace(TP.VALORPAGOVARCHAR,',','.')) as float) as total FROM TVENDANFCE AS TV INNER JOIN TFORMAPAGAMENTONFCE AS TP on TP.CODNFCE = TV.CONTROLE WHERE TV.DATAEHORACADASTRO > '" + str(AlegriaDeBrincar.getLastDataInsert(self,"vendas")) + "' and TV.DATAEHORACADASTRO >= dateadd (-"+ str(self.c["cacheDay"])+" day to current_date) and TP.VALORPAGOVARCHAR <> '0,00'"
+        print(string)
         result = AlegriaDeBrincar.selectFDB(self,string)
 
         while len(result) > 0:
@@ -159,7 +160,7 @@ class AlegriaDeBrincar:
         AlegriaDeBrincar.insertDB(self,string)
 
     def insertDay(self):
-        string = "SELECT cast(TV.DATAEHORACADASTRO as date),TP.CODESPECIE,cast((replace(TP.VALORPAGOVARCHAR,',','.')) as float) as total FROM TVENDANFCE AS TV INNER JOIN TFORMAPAGAMENTONFCE AS TP on TP.CODNFCE = TV.NUMERONFCCE WHERE cast(TV.DATAEHORACADASTRO as date) < cast('Now' as date) AND cast(TV.DATAEHORACADASTRO as date) >= '" + str(AlegriaDeBrincar.getLastDataInsert(self,"vendas_mes")) + "'"
+        string = "SELECT cast(TV.DATAEHORACADASTRO as date),TP.CODESPECIE,cast((replace(TP.VALORPAGOVARCHAR,',','.')) as float) as total FROM TVENDANFCE AS TV INNER JOIN TFORMAPAGAMENTONFCE AS TP on TP.CODNFCE = TV.CONTROLE WHERE cast(TV.DATAEHORACADASTRO as date) < cast('Now' as date) AND cast(TV.DATAEHORACADASTRO as date) >= '" + str(AlegriaDeBrincar.getLastDataInsert(self,"vendas_mes")) + "'"
         
         result = AlegriaDeBrincar.selectFDB(self,string)
         
